@@ -102,7 +102,7 @@ class ProxyManager:
 
         self._executor_queue.put(task)
 
-    def __enter__(self):
+    def start(self):
         self._pool.start()
 
         def fn():
@@ -120,12 +120,18 @@ class ProxyManager:
         for _ in range(self._executor_workers):
             self._executor.submit(fn)
 
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def stop(self):
         self._executor_queue.join()
 
         self._executor_running = False
         self._executor.shutdown(True)
 
         self._pool.end()
+
+    def __enter__(self):
+        self.start()
+
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.stop()
